@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Ad;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -18,7 +18,9 @@ sub _user_setable_attributes {
                  accountID
                  adGroupID
                  adOptimizationWeight
-                 clickThroughURLSettings
+                 clickThroughURLs
+                 createTimestamp
+                 lastUpdateTimestamp
                  libraryAdID
                  status
                  type
@@ -27,8 +29,6 @@ sub _user_setable_attributes {
 
 sub _read_only_attributes {
     return ( qw/
-                 createTimestamp
-                 lastUpdateTimestamp
            / );
 }
 
@@ -40,7 +40,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -59,7 +59,9 @@ Creates a new instance
     accountID
     adGroupID
     adOptimizationWeight
-    clickThroughURLSettings
+    clickThroughURLs
+    createTimestamp
+    lastUpdateTimestamp
     libraryAdID
     status
     type
@@ -70,8 +72,6 @@ Creates a new instance
 
 =over 8
 
-    createTimestamp
-    lastUpdateTimestamp
 
 =back
 
