@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::RateAdjustment;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -22,7 +22,7 @@ sub _user_setable_attributes {
                  rateCardID
                  startDate
                  targetCPM
-                 targetingAttributeDescriptors
+                 targetingAttributeDescriptorsWithAny
             /  );
 }
 
@@ -39,7 +39,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -62,7 +62,7 @@ Creates a new instance
     rateCardID
     startDate
     targetCPM
-    targetingAttributeDescriptors
+    targetingAttributeDescriptorsWithAny
 
 =back
 
