@@ -12,15 +12,15 @@ use Yahoo::Marketing::APT::BidDescriptor;
 sub test_can_create_bid_descriptor_and_set_all_fields : Test(4) {
 
     my $bid_descriptor = Yahoo::Marketing::APT::BidDescriptor->new
-                                                        ->bid( 'bid' )
                                                         ->bidDate( '2009-01-06T17:51:55' )
+                                                        ->maxBid( 'max bid' )
                                                         ->pricingModel( 'pricing model' )
                    ;
 
     ok( $bid_descriptor );
 
-    is( $bid_descriptor->bid, 'bid', 'can get bid' );
     is( $bid_descriptor->bidDate, '2009-01-06T17:51:55', 'can get 2009-01-06T17:51:55' );
+    is( $bid_descriptor->maxBid, 'max bid', 'can get max bid' );
     is( $bid_descriptor->pricingModel, 'pricing model', 'can get pricing model' );
 
 };
